@@ -48,8 +48,9 @@ null = _null()
 
 class _drop(object):
     """ Represents a value that will be dropped from the schema if it
-    is missing during *deserialization*.  Passed as a value to the
-    `missing` keyword argument of :class:`SchemaNode`.
+    is missing during *serialization* or *deserialization*.  Passed as
+    a value to the `missing` or `default` keyword argument
+    of :class:`SchemaNode`.
     """
     def __repr__(self):
         return '<colander.drop>'
@@ -205,6 +206,18 @@ class Invalid(Exception):
         result of an execution of this exception's ``asdict`` method"""
         return pprint.pformat(self.asdict())
 
+
+class UnsupportedFields(Invalid):
+    """
+    Exception used when schema object detect unknown fields in the
+    cstruct during deserialize.
+    """
+
+    def __init__(self, node, fields, msg=None):
+        super(UnsupportedFields, self).__init__(node, msg)
+        self.fields = fields
+
+
 class All(object):
     """ Composite validator which succeeds if none of its
     subvalidators raises an :class:`colander.Invalid` exception"""
@@ -667,11 +680,10 @@ class Mapping(SchemaType):
 
         if self.unknown == 'raise':
             if value:
-                raise Invalid(
-                    node,
-                    _('Unrecognized keys in mapping: "${val}"',
-                      mapping={'val':value})
-                    )
+                raise UnsupportedFields(
+                    node, value,
+                    msg=_('Unrecognized keys in mapping: "${val}"',
+                          mapping={'val': value}))
 
         elif self.unknown == 'preserve':
             result.update(value)
@@ -1014,13 +1026,20 @@ class Sequence(Positional, SchemaType):
         error = None
         result = []
 
+        subnode = node.children[0]
         for num, subval in enumerate(value):
+            if subval is drop or (subval is null and subnode.default is drop):
+                continue
             try:
-                result.append(callback(node.children[0], subval))
+                sub_result = callback(subnode, subval)
             except Invalid as e:
                 if error is None:
                     error = Invalid(node)
                 error.add(e, num)
+            else:
+                if sub_result is drop:
+                    continue
+                result.append(sub_result)
 
         if error is not None:
             raise error
@@ -1833,8 +1852,10 @@ class _SchemaNode(object):
     - ``typ``: The 'type' for this node can optionally be passed in as a
       keyword argument. See the documentation for the positional arg above.
 
-    - ``default``: The default serialization value for this node.
-      Default: :attr:`colander.null`.
+    - ``default``: The default serialization value for this node when
+      not set.  If ``default`` is :attr:`colander.drop`, the node
+      will be dropped from schema serialization.  If not provided,
+      the node will be serialized to :attr:`colander.null`.
 
     - ``missing``: The default deserialization value for this node.  If it is
       not provided, the missing value of this node will be the special marker
@@ -1842,7 +1863,7 @@ class _SchemaNode(object):
       'required'.  When ``missing`` is :attr:`colander.required`, the
       ``required`` computed attribute will be ``True``.  When ``missing`` is
       :attr:`colander.drop`, the node is dropped from the schema if it isn't
-      set during serialization/deserialization.
+      set during deserialization.
 
     - ``missing_msg``: Optional error message to be used if the value is
       required and missing.
@@ -1908,15 +1929,14 @@ class _SchemaNode(object):
         return node
 
     def __init__(self, *arg, **kw):
-        # bw compat forces us to treat first arg as type always
+        # bw compat forces us to treat first arg as type if not a _SchemaNode
         if 'typ' in kw:
             self.typ = kw.pop('typ')
-            _add_node_children(self, arg)
-        elif arg:
-            self.typ = arg[0]
-            _add_node_children(self, arg[1:])
+        elif arg and not isinstance(arg[0], _SchemaNode):
+            self.typ, arg = arg[0], arg[1:]
         else:
             self.typ = self.schema_type()
+        _add_node_children(self, arg)
 
         # bw compat forces us to manufacture a title if one is not supplied
         title = kw.get('title', self.title)
